package com.example.elbuenopeso.database

import android.content.ContentValues
import android.content.Context
import android.database.Cursor
import android.database.SQLException
import android.database.sqlite.SQLiteDatabase
import android.util.Log
import com.example.elbuenopeso.models.AdModel


class DBManager //init(); // Useful for adding ads for the first time.
private constructor(private val context: Context) {
    private var dbHelper: DBHelper? = null
    private var database: SQLiteDatabase? = null
    @Throws(SQLException::class)
    fun open(): DBManager {
        this.dbHelper = DBHelper(this.context)
        this.database = this.dbHelper!!.writableDatabase
        return this
    }

    fun close() {
        this.dbHelper?.close()
    }

    // Add ads manually.
    fun init() {
        this.open()
        this.insert(
            AdModel(
                "Wood",
                "Douai",
                "https://media.istockphoto.com/id/134253640/photo/construction-of-a-wooden-roof-frame-underway.jpg?s=612x612&w=0&k=20&c=e5gUkic9LGQWahIdHozOsEzHKy_HtsmvmtOHmYsejSU=",
                25.0
            )
        )
        this.insert(
            AdModel(
                "Steel",
                "Lille",
                "https://as2.ftcdn.net/v2/jpg/03/91/83/87/1000_F_391838708_4HFADW5beay2VVlnoual6Qi5fWeIaD9V.jpg",25.0
            )
        )
        this.insert(
            AdModel(
                "Clay",
                "Douai",
                "https://constrofacilitator.com/wp-content/uploads/2020/02/clay-in-construction.jpg",25.0
            )
        )
        this.insert(
            AdModel(
                "Metal",
                "Lyon",
                "https://www.meto-constructions.fr/wp-content/uploads/2018/12/IMG_6067.jpg",25.0
            )
        )
        this.insert(
            AdModel(
                "Glass",
                "Valenciennes",
                "https://i0.wp.com/www.tipsnepal.com/wp-content/uploads/2020/09/simple-float-glass-1505049573-3306125.jpeg?resize=500%2C317&quality=100&strip=all&ssl=1",25.0
            )
        )
        this.insert(
            AdModel(
                "Wood",
                "Orchies",
                "https://yieldpro.com/wp-content/uploads/2020/08/lumber1.jpg",25.0
            )
        )
    }

    fun insert(ad: AdModel) {
        val contentValue = ContentValues()
        contentValue.put(DBHelper.TITLE, ad.title)
        contentValue.put(DBHelper.ADDRESS, ad.address)
        contentValue.put(DBHelper.IMAGE, ad.image)
        this.database!!.insert(DBHelper.TABLE_NAME, null, contentValue)
    }

    fun fetch(): Cursor? {
        val columns: Array<String> =
            arrayOf(DBHelper._ID, DBHelper.TITLE, DBHelper.ADDRESS, DBHelper.IMAGE, DBHelper.PRIX)
        columns.forEach { e -> Log.i(null, e) }
        val cursor = this.database!!.query(DBHelper.TABLE_NAME, columns, null, null, null, null, null)
        cursor?.moveToFirst()
        return cursor
    }

    fun update(_id: Long, ad: AdModel): Int {
        val contentValues = ContentValues()
        contentValues.put(DBHelper.TITLE, ad.title)
        contentValues.put(DBHelper.ADDRESS, ad.address)
        contentValues.put(DBHelper.IMAGE, ad.image)
        return this.database!!.update(
            DBHelper.TABLE_NAME,
            contentValues,
            DBHelper._ID + " = " + _id,
            null
        )
    }

    fun delete(_id: Long) {
        this.database!!.delete(DBHelper.TABLE_NAME, DBHelper._ID + "=" + _id, null)
    }

    fun getById(id: Int): AdModel? {
        return this.dbHelper?.getById(id)
    }

    companion object {
        var DBManager: DBManager? = null
        // normalement pas de fuite, puisque 1 seul contexte
        fun getDBManager(context: Context): DBManager? {
            return if (this.DBManager == null) {
                DBManager(context)
            } else this.DBManager
        }
    }
}

